describe('Feedbacks', () => {
  beforeEach(() => {
    const userEmail = Cypress.env('USER_EMAIL');
    const userPassword = Cypress.env('USER_PASSWORD');
    cy.login(userEmail, userPassword);
  });
  it('should send feedback correctly with message', () => {
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#feedbackRecipientWrapper').click();
    cy.contains('Eduarda Keller').click();
    cy.get('#message').click().type('Essa é uma mensagem de teste');

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('1');
    cy.get('#sendFeedbackButton').click();

    cy.contains('Sucesso').should('be.visible');

    cy.get('.MuiSvgIcon-root[data-testid="HighlightOffIcon"]').click();
  });

  it('should send feedback correctly with empty message', () => {
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#feedbackRecipientWrapper').click();
    cy.contains('Julia Makowski').click();

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('1');
    cy.get('#sendFeedbackButton').click();

    cy.contains('Sucesso').should('be.visible');

    cy.get('.MuiSvgIcon-root[data-testid="HighlightOffIcon"]').click();
  });

  it('should not send feedback if value is invalid', () => {
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#feedbackRecipientWrapper').click();
    cy.contains('Arthur Both').click();
    cy.get('#message').click().type('Essa é uma mensagem de teste');

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('0');

    cy.get('#sendFeedbackButton').click();

    cy.get('.feedbackModal_sendClapFooterWrapper__poR_T > span')
      .should('be.visible')
      .should('have.text', 'Por favor, selecione a quantidade de aplausos');
  });

  it('should not send feedback if there is no receiver', () => {
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#message').click().type('Essa é uma mensagem de teste');

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('1');
    cy.get('#sendFeedbackButton').click();

    cy.get('#feedbackRecipientWrapper > span')
      .should('be.visible')
      .should(
        'have.text',
        'Por favor, selecione um destinatário para o feedback',
      );
  });
  
  it('should delete a received feedback', () => {
    cy.wait(10000)
    cy.get('[data-testid="DeleteOutlineOutlinedIcon"]').first().click();
    cy.get('#buttonConfirmar').click();
    cy.contains('Sucesso').should('be.visible');
    cy.get('[data-testid="HighlightOffIcon"]').click();
  });

  it('should cancel a deletion of received feedback', () => {
    let initialFeedbacks: number = 0;
    cy.get('[class*="home_contentBox"]', { timeout: 10000 })
    cy.get('[id="feedback1"]', { timeout: 10000 })
      .should('be.visible')
      .its('length')
      .then((length) => {
        initialFeedbacks = length as number;
      })
      .then(() => {
        cy.get('[data-testid="DeleteOutlineOutlinedIcon"]').first().click();
        cy.get('#buttonCancelar').click();
        cy.get('.userMessageModal_modal__6hn13').should('not.exist');
        cy.get('[class*="home_contentBox"]')
        cy.get('[id="feedback1"]')
          .should('be.visible')
          .its('length')
          .should('eq', initialFeedbacks);
      });
  });
});
